@@ -22,6 +22,10 @@ function(lmom) {
     PI3 <- 3*pi
     ROOTPI <- sqrt(pi)
 
+    if(length(lmom$L1) == 0) { # convert to named L-moments
+      lmom <- lmorph(lmom)     # nondestructive conversion!
+    }
+
     if(! are.lmom.valid(lmom)) {
       warning("L-moments are invalid")
       return()
